@@ -1,5 +1,5 @@
 
-from typing import TypeVar, Type
+from typing import TypeVar, Type, Generic
 
 from BotCore import DAO
 from BotCore.ModelInfo import ModelInfo
@@ -8,11 +8,11 @@ T = TypeVar("T", bound=ModelInfo)
 D = TypeVar("D", bound=DAO)
 
 
-class Service:
+class Service(Generic[T, D]):
 
 	def __init__(self, model: Type[T], dao: D):
-		self.model = model
-		self.dao = dao
+		self.model: Type[T] = model
+		self.dao: D = dao
 
 	def create(self, **kwargs):
 		return self.dao.create(**kwargs)
